@@ -41,13 +41,13 @@ where
 
 #[derive(Debug, Serialize, Deserialize)]
 struct YamlFile {
-    context: Option<Vec<YamlContext>>,
-    builder: Option<Vec<YamlContext>>,
+    contexts: Option<Vec<YamlContext>>,
+    builders: Option<Vec<YamlContext>>,
     #[serde(default, deserialize_with = "deserialize_some")]
-    module: Option<Option<Vec<YamlModule>>>,
+    modules: Option<Option<Vec<YamlModule>>>,
     #[serde(default, deserialize_with = "deserialize_some")]
-    app: Option<Option<Vec<YamlModule>>>,
-    import: Option<Vec<Import>>,
+    apps: Option<Option<Vec<YamlModule>>>,
+    imports: Option<Vec<Import>>,
     subdirs: Option<Vec<String>>,
     defaults: Option<HashMap<String, YamlModule>>,
     #[serde(skip)]
@@ -65,10 +65,10 @@ struct YamlContext {
     name: String,
     parent: Option<String>,
     env: Option<Env>,
-    select: Option<Vec<String>>,
-    disable: Option<Vec<String>>,
-    rule: Option<Vec<Rule>>,
-    var_options: Option<im::HashMap<String, MergeOption>>,
+    selects: Option<Vec<String>>,
+    disables: Option<Vec<String>>,
+    rules: Option<Vec<Rule>>,
+    var_options: Option<imbl::HashMap<String, MergeOption>>,
     tasks: Option<HashMap<String, Task>>,
     #[serde(skip)]
     is_builder: bool,
@@ -95,7 +95,8 @@ struct YamlModule {
     depends: Option<Vec<StringOrMapString>>,
     selects: Option<Vec<String>>,
     uses: Option<Vec<String>>,
-    disable: Option<Vec<String>>,
+    #[serde(alias = "disables")]
+    conflicts: Option<Vec<String>>,
     #[serde(default = "default_as_false")]
     notify_all: bool,
     sources: Option<Vec<StringOrMapString>>,
@@ -119,7 +120,7 @@ impl YamlModule {
             depends: None,
             selects: None,
             uses: None,
-            disable: None,
+            conflicts: None,
             notify_all: false,
             sources: None,
             srcdir: None,
@@ -136,8 +137,8 @@ impl YamlModule {
     fn get_contexts(&self) -> Vec<Option<&String>> {
         if let Some(contexts) = &self.context {
             match contexts {
-                StringOrVecString::Single(single) => vec![Some(&single)],
-                StringOrVecString::List(list) => list.iter().map(|x| Some(x)).collect_vec(),
+                StringOrVecString::Single(single) => vec![Some(single)],
+                StringOrVecString::List(list) => list.iter().map(Some).collect_vec(),
             }
         } else {
             return vec![None];
@@ -166,11 +167,11 @@ struct YamlModuleEnv {
 fn process_removes(strings: &mut Vec<Dependency<String>>) {
     let removals = strings
         .iter()
-        .filter(|x| x.get_name().starts_with("-"))
+        .filter(|x| x.get_name().starts_with('-'))
         .map(|x| x.get_name()[1..].to_string())
         .collect::<HashSet<_>>();
 
-    strings.retain(|x| !(x.get_name().starts_with("-") || removals.contains(&x.get_name()[..])));
+    strings.retain(|x| !(x.get_name().starts_with('-') || removals.contains(&x.get_name()[..])));
 }
 
 pub fn dependency_from_string(dep_name: &String) -> Dependency<String> {
@@ -267,7 +268,7 @@ pub fn load(filename: &Path, build_dir: &Path) -> Result<(ContextBag, FileTreeSt
         let new_index_start = yaml_datas.len();
 
         // load all yaml documents from filename, append to yaml_datas
-        yaml_datas.extend(load_all(&include, new_index_start)?.drain(..));
+        yaml_datas.append(&mut load_all(include, new_index_start)?);
         filenames_pos += 1;
 
         let new_index_end = yaml_datas.len();
@@ -288,7 +289,7 @@ pub fn load(filename: &Path, build_dir: &Path) -> Result<(ContextBag, FileTreeSt
                     ));
                 }
             }
-            if let Some(imports) = &new.import {
+            if let Some(imports) = &new.imports {
                 for import in imports {
                     // TODO: `import.handle()` does the actual git checkout (or whatever
                     // import action), so probably better handling of any errors is
@@ -336,7 +337,7 @@ pub fn load(filename: &Path, build_dir: &Path) -> Result<(ContextBag, FileTreeSt
             )
             .with_context(|| format!("{:?}: adding context \"{}\"", &filename, &context_name))?;
         context_.env = context.env.clone();
-        if let Some(rules) = &context.rule {
+        if let Some(rules) = &context.rules {
             context_.rules = Some(IndexMap::new());
             for rule in rules {
                 let mut rule = rule.clone();
@@ -352,7 +353,7 @@ pub fn load(filename: &Path, build_dir: &Path) -> Result<(ContextBag, FileTreeSt
         // populate "early env"
         let relpath = {
             let relpath = filename.parent().unwrap().to_str().unwrap();
-            if relpath == "" {
+            if relpath.is_empty() {
                 ".".to_string()
             } else {
                 relpath.to_string()
@@ -387,14 +388,14 @@ pub fn load(filename: &Path, build_dir: &Path) -> Result<(ContextBag, FileTreeSt
 
         context_.defined_in = Some(filename.clone());
 
-        context_.disable = context.disable.clone();
+        context_.disable = context.disables.clone();
 
         // collect context level "select:"
-        if let Some(select) = &context.select {
+        if let Some(select) = &context.selects {
             context_.select = Some(
                 select
                     .iter()
-                    .map(|dep_name| dependency_from_string(dep_name))
+                    .map(dependency_from_string)
                     .collect::<Vec<_>>(),
             );
         }
@@ -430,7 +431,7 @@ pub fn load(filename: &Path, build_dir: &Path) -> Result<(ContextBag, FileTreeSt
         };
 
         let mut module = match defaults {
-            Some(defaults) => Module::from(defaults, name.clone(), context.cloned()),
+            Some(defaults) => Module::from(defaults, name, context.cloned()),
             None => Module::new(name, context.cloned()),
         };
 
@@ -467,8 +468,9 @@ pub fn load(filename: &Path, build_dir: &Path) -> Result<(ContextBag, FileTreeSt
         // "depends" means both select and use a module
         // a build configuration fails if a selected or depended on module is not
         // available.
-        // "disable" is only valid for binaries ("apps"), and will make any module
-        // with the specified name unavailable in the binary's build context
+        // "conflicts" will make any module with the specified name unavailable
+        // in the binary's build context, if the module specifying a conflict
+        // is part of the dependency tree
         //
         if let Some(selects) = &module.selects {
             // println!("selects:");
@@ -506,22 +508,13 @@ pub fn load(filename: &Path, build_dir: &Path) -> Result<(ContextBag, FileTreeSt
                 }
             }
         }
-        if let Some(disable) = &module.disable {
-            if m.is_binary {
-                if let None = m.disable {
-                    m.disable = Some(Vec::new());
-                }
-                // println!("disables:");
-                for dep_name in disable {
-                    // println!("- {}", dep_name);
-                    m.disable.as_mut().unwrap().push(dep_name.clone());
-                }
-            } else {
-                return Err(anyhow!(
-                    "{:?}: module {}: \"disable\" not allowed on regular (non-app) modules!",
-                    m.defined_in.unwrap(),
-                    m.name
-                ));
+
+        if let Some(conflicts) = &module.conflicts {
+            if m.conflicts.is_none() {
+                m.conflicts = Some(Vec::new());
+            }
+            for dep_name in conflicts {
+                m.conflicts.as_mut().unwrap().push(dep_name.clone());
             }
         }
 
@@ -569,7 +562,7 @@ pub fn load(filename: &Path, build_dir: &Path) -> Result<(ContextBag, FileTreeSt
             // if there are optional sources, merge them into the module's
             // optional sources map
             if !sources_optional.is_empty() {
-                if let None = m.sources_optional {
+                if m.sources_optional.is_none() {
                     m.sources_optional = Some(IndexMap::new());
                 }
                 let m_sources_optional = m.sources_optional.as_mut().unwrap();
@@ -655,14 +648,14 @@ pub fn load(filename: &Path, build_dir: &Path) -> Result<(ContextBag, FileTreeSt
     // this needs to be done before collecting modules, as that requires
     // contexts to be finalized.
     for data in &yaml_datas {
-        for (list, is_builder) in [(&data.context, false), (&data.builder, true)].iter() {
+        for (list, is_builder) in [(&data.contexts, false), (&data.builders, true)].iter() {
             if let Some(context_list) = list {
                 for context in context_list {
                     convert_context(
                         context,
                         &mut contexts,
                         *is_builder,
-                        &data.filename.as_ref().unwrap(),
+                        data.filename.as_ref().unwrap(),
                         &data.import_root,
                     )?;
                 }
@@ -702,23 +695,22 @@ pub fn load(filename: &Path, build_dir: &Path) -> Result<(ContextBag, FileTreeSt
         // determine "defaults: module: ..." from yaml document
         let mut module_defaults = if let Some(defaults) = &data.defaults {
             if let Some(module_defaults) = defaults.get(key) {
-                let context =
-                    &module_defaults
-                        .context
-                        .as_ref()
-                        .map_or(None, |context| match context {
-                            StringOrVecString::List(_) => {
-                                panic!("module defaults with context _list_")
-                            }
-                            StringOrVecString::Single(context) => Some(context),
-                        });
+                let context = &module_defaults
+                    .context
+                    .as_ref()
+                    .and_then(|context| match context {
+                        StringOrVecString::List(_) => {
+                            panic!("module defaults with context _list_")
+                        }
+                        StringOrVecString::Single(context) => Some(context),
+                    });
 
                 Some(
                     convert_module(
-                        &module_defaults,
+                        module_defaults,
                         *context,
                         is_binary,
-                        &data.filename.as_ref().unwrap(),
+                        data.filename.as_ref().unwrap(),
                         &data.import_root,
                         subdir_defaults,
                         build_dir,
@@ -731,7 +723,7 @@ pub fn load(filename: &Path, build_dir: &Path) -> Result<(ContextBag, FileTreeSt
         } else {
             None
         };
-        if let None = module_defaults {
+        if module_defaults.is_none() {
             if let Some(subdir_defaults) = subdir_defaults {
                 module_defaults = Some(subdir_defaults.clone());
             }
@@ -749,7 +741,7 @@ pub fn load(filename: &Path, build_dir: &Path) -> Result<(ContextBag, FileTreeSt
         );
         let app_defaults = get_defaults(data, &subdir_app_defaults_map, "app", true, build_dir);
 
-        if let Some(_) = data.subdirs {
+        if data.subdirs.is_some() {
             if let Some(module_defaults) = &module_defaults {
                 subdir_module_defaults_map.insert(data.doc_idx.unwrap(), module_defaults.clone());
             }
@@ -758,16 +750,16 @@ pub fn load(filename: &Path, build_dir: &Path) -> Result<(ContextBag, FileTreeSt
             }
         }
 
-        for (list, is_binary) in [(&data.module, false), (&data.app, true)].iter() {
+        for (list, is_binary) in [(&data.modules, false), (&data.apps, true)].iter() {
             if let Some(module_list) = list {
                 if let Some(module_list) = module_list {
                     for module in module_list {
                         for context in module.get_contexts() {
                             contexts.add_module(convert_module(
-                                &module,
+                                module,
                                 context,
                                 *is_binary,
-                                &data.filename.as_ref().unwrap(),
+                                data.filename.as_ref().unwrap(),
                                 &data.import_root,
                                 if *is_binary {
                                     app_defaults.as_ref()
@@ -778,22 +770,20 @@ pub fn load(filename: &Path, build_dir: &Path) -> Result<(ContextBag, FileTreeSt
                             )?)?;
                         }
                     }
-                } else {
-                    if *is_binary {
-                        // if an app list is empty, add a default entry.
-                        // this allows a convenient file only containing "app:"
-                        let module = YamlModule::default(*is_binary);
-                        for context in module.get_contexts() {
-                            contexts.add_module(convert_module(
-                                &module,
-                                context,
-                                *is_binary,
-                                &data.filename.as_ref().unwrap(),
-                                &data.import_root,
-                                app_defaults.as_ref(),
-                                build_dir,
-                            )?)?;
-                        }
+                } else if *is_binary {
+                    // if an app list is empty, add a default entry.
+                    // this allows a convenient file only containing "app:"
+                    let module = YamlModule::default(*is_binary);
+                    for context in module.get_contexts() {
+                        contexts.add_module(convert_module(
+                            &module,
+                            context,
+                            *is_binary,
+                            data.filename.as_ref().unwrap(),
+                            &data.import_root,
+                            app_defaults.as_ref(),
+                            build_dir,
+                        )?)?;
                     }
                 }
             }
