@@ -11,7 +11,7 @@ extern crate derive_builder;
 extern crate pathdiff;
 
 use core::sync::atomic::AtomicBool;
-use std::collections::HashSet;
+
 use std::env;
 use std::iter;
 use std::path::{Path, PathBuf};
@@ -98,7 +98,7 @@ impl<'a: 'b, 'b> Build<'b> {
         };
 
         /* fixup name to "$builder_name:$binary_name" */
-        build.build_context.name.push_str(&":");
+        build.build_context.name.push(':');
         build.build_context.name.push_str(&build.binary.name);
 
         /* collect environment from builder */
@@ -130,12 +130,16 @@ impl<'a: 'b, 'b> Build<'b> {
         module: &'m Module,
         module_set: &mut IndexMap<&'m String, &'m Module>,
         if_then_deps: &mut IndexMap<String, Vec<Dependency<String>>>,
-        disabled_modules: &HashSet<String>,
+        disabled_modules: &mut IndexSet<String>,
     ) -> Result<(), Error> {
         let prev_len = module_set.len();
         let if_then_deps_prev_len = if_then_deps.len();
+        let disabled_modules_prev_len = disabled_modules.len();
 
         module_set.insert(&module.name, module);
+        if let Some(conflicts) = &module.conflicts {
+            disabled_modules.extend(conflicts.iter().cloned())
+        }
 
         let mut late_if_then_deps = Vec::new();
         if let Some(deps) = if_then_deps.get(&module.name) {
@@ -152,7 +156,7 @@ impl<'a: 'b, 'b> Build<'b> {
                     } else {
                         if_then_deps
                             .entry(other.clone())
-                            .or_insert_with(|| Vec::new())
+                            .or_insert_with(Vec::new)
                             .push(Dependency::Hard(name.clone()));
                         continue;
                     }
@@ -163,7 +167,7 @@ impl<'a: 'b, 'b> Build<'b> {
                     } else {
                         if_then_deps
                             .entry(other.clone())
-                            .or_insert_with(|| Vec::new())
+                            .or_insert_with(Vec::new)
                             .push(Dependency::Soft(name.clone()));
 
                         continue;
@@ -179,9 +183,10 @@ impl<'a: 'b, 'b> Build<'b> {
                 if !optional {
                     module_set.truncate(prev_len);
                     if_then_deps.truncate(if_then_deps_prev_len);
+                    disabled_modules.truncate(disabled_modules_prev_len);
 
                     bail!(
-                        "binary {} for builder {}: {} depends on disabled module {}",
+                        "binary {} for builder {}: {} depends on disabled/conflicted module {}",
                         self.binary.name,
                         self.builder.name,
                         module.name,
@@ -200,6 +205,7 @@ impl<'a: 'b, 'b> Build<'b> {
                     } else {
                         module_set.truncate(prev_len);
                         if_then_deps.truncate(if_then_deps_prev_len);
+                        disabled_modules.truncate(disabled_modules_prev_len);
                         bail!(
                             "binary {} for builder {}: {} depends on unavailable module {}",
                             self.binary.name,
@@ -217,6 +223,7 @@ impl<'a: 'b, 'b> Build<'b> {
                 if !optional {
                     module_set.truncate(prev_len);
                     if_then_deps.truncate(if_then_deps_prev_len);
+                    disabled_modules.truncate(disabled_modules_prev_len);
                     return Err(x);
                 }
             }
@@ -226,7 +233,7 @@ impl<'a: 'b, 'b> Build<'b> {
 
     fn resolve_selects(
         &self,
-        disabled_modules: &HashSet<String>,
+        disabled_modules: &mut IndexSet<String>,
     ) -> Result<IndexMap<&String, &Module>, Error> {
         let mut modules = IndexMap::new();
         let mut if_then_deps = IndexMap::new();
@@ -264,14 +271,21 @@ fn ninja_run(
     ninja_buildfile: &Path,
     verbose: bool,
     targets: Option<Vec<PathBuf>>,
+    jobs: Option<usize>,
 ) -> Result<i32, Error> {
-    let ninja_exit = NinjaCmdBuilder::default()
+    let mut ninja_cmd = NinjaCmdBuilder::default();
+
+    ninja_cmd
         .verbose(verbose)
         .build_file(ninja_buildfile.to_str().unwrap())
-        .targets(targets)
-        .build()
-        .unwrap()
-        .run()?;
+        .targets(targets);
+
+    if let Some(jobs) = jobs {
+        ninja_cmd.jobs(jobs);
+    }
+
+    let ninja_exit = ninja_cmd.build().unwrap().run()?;
+
     match ninja_exit.code() {
         Some(code) => match code {
             0 => Ok(code),
@@ -367,6 +381,14 @@ fn clap() -> clap::Command<'static> {
                         .help("be verbose (e.g., show command lines)")
                         .multiple_occurrences(true),
                 )
+                .arg(
+                    Arg::new("jobs")
+                        .short('j')
+                        .long("jobs")
+                        .help("how many compile jobs to run in parallel")
+                        .takes_value(true)
+                        .validator(|val| val.parse::<usize>()),
+                )
                 .arg(
                     Arg::new("select")
                         .short('s')
@@ -426,6 +448,14 @@ fn clap() -> clap::Command<'static> {
                         .help("be verbose (e.g., show command lines)")
                         .multiple_occurrences(true),
                 )
+                .arg(
+                    Arg::new("jobs")
+                        .short('j')
+                        .long("jobs")
+                        .help("how many compile jobs to run in parallel")
+                        .takes_value(true)
+                        .validator(|val| val.parse::<usize>()),
+                )
                 .arg(
                     Arg::new("builder")
                         .short('b')
@@ -512,10 +542,8 @@ fn try_main() -> Result<i32> {
 
     thread::spawn(move || {
         for sig in signals.forever() {
-            if sig == SIGINT {
-                if !IGNORE_SIGINT.load(std::sync::atomic::Ordering::SeqCst) {
-                    std::process::exit(130);
-                }
+            if sig == SIGINT && !IGNORE_SIGINT.load(std::sync::atomic::Ordering::SeqCst) {
+                std::process::exit(130);
             }
         }
     });
@@ -548,28 +576,34 @@ fn try_main() -> Result<i32> {
             let build_dir = PathBuf::from(build_matches.value_of("build-dir").unwrap());
 
             // collect builder names from args
-            let builders = match build_matches.values_of_lossy("builders") {
-                Some(mut values) => Selector::Some(values.drain(..).collect::<IndexSet<String>>()),
+            let builders = match build_matches.values_of("builders") {
+                Some(values) => {
+                    Selector::Some(values.map(String::from).collect::<IndexSet<String>>())
+                }
                 None => Selector::All,
             };
 
             // collect app names from args
-            let apps = match build_matches.values_of_lossy("apps") {
-                Some(mut values) => Selector::Some(values.drain(..).collect::<IndexSet<String>>()),
+            let apps = match build_matches.values_of("apps") {
+                Some(values) => {
+                    Selector::Some(values.map(String::from).collect::<IndexSet<String>>())
+                }
                 None => Selector::All,
             };
 
+            let jobs = build_matches
+                .value_of("jobs")
+                .map(|val| val.parse::<usize>().unwrap());
+
             println!("building {} for {}", &apps, &builders);
 
             // collect CLI selected modules
             let select = build_matches.values_of_lossy("select");
             // convert CLI --select strings to Vec<Dependency>
-            let select = select.map_or(None, |mut vec| {
-                Some(
-                    vec.drain(..)
-                        .map(|dep_name| crate::data::dependency_from_string(&dep_name))
-                        .collect_vec(),
-                )
+            let select = select.map(|mut vec| {
+                vec.drain(..)
+                    .map(|dep_name| crate::data::dependency_from_string(&dep_name))
+                    .collect_vec()
             });
 
             let disable = build_matches.values_of_lossy("disable");
@@ -638,7 +672,7 @@ fn try_main() -> Result<i32> {
             };
 
             let ninja_build_file = get_ninja_build_file(&build_dir, &mode);
-            ninja_run(ninja_build_file.as_path(), verbose > 0, targets)?;
+            ninja_run(ninja_build_file.as_path(), verbose > 0, targets, jobs)?;
         }
         Some(("task", task_matches)) => {
             let verbose = task_matches.occurrences_of("verbose");
@@ -647,15 +681,17 @@ fn try_main() -> Result<i32> {
             let builder = task_matches.value_of("builder");
             let app = task_matches.value_of("app");
 
+            let jobs = task_matches
+                .value_of("jobs")
+                .map(|val| val.parse::<usize>().unwrap());
+
             // collect CLI selected modules
             let select = task_matches.values_of_lossy("select");
             // convert CLI --select strings to Vec<Dependency>
-            let select = select.map_or(None, |mut vec| {
-                Some(
-                    vec.drain(..)
-                        .map(|dep_name| crate::data::dependency_from_string(&dep_name))
-                        .collect_vec(),
-                )
+            let select = select.map(|mut vec| {
+                vec.drain(..)
+                    .map(|dep_name| crate::data::dependency_from_string(&dep_name))
+                    .collect_vec()
             });
 
             let disable = task_matches.values_of_lossy("disable");
@@ -724,7 +760,7 @@ fn try_main() -> Result<i32> {
                 .filter(|(builder, app, build_info)| {
                     builders.selects(builder)
                         && apps.selects(app)
-                        && build_info.tasks.contains_key(task.into())
+                        && build_info.tasks.contains_key(task)
                 })
                 .collect();
 
@@ -738,7 +774,7 @@ fn try_main() -> Result<i32> {
                 return Err(anyhow!("please specify one of these."));
             }
 
-            if builds.len() < 1 {
+            if builds.is_empty() {
                 return Err(anyhow!("no matching target for task \"{}\" found.", task));
             }
 
@@ -746,11 +782,11 @@ fn try_main() -> Result<i32> {
             let targets = Some(vec![build.2.out.clone()]);
 
             let task_name = task;
-            let task = build.2.tasks.get(task.into()).unwrap();
+            let task = build.2.tasks.get(task).unwrap();
 
             if task.build_app() {
-                let ninja_build_file = get_ninja_build_file(&build_dir, &mode);
-                if ninja_run(ninja_build_file.as_path(), verbose > 0, targets)? != 0 {
+                let ninja_build_file = get_ninja_build_file(build_dir, &mode);
+                if ninja_run(ninja_build_file.as_path(), verbose > 0, targets, jobs)? != 0 {
                     return Err(anyhow!("build error"));
                 };
             }
@@ -776,7 +812,7 @@ fn try_main() -> Result<i32> {
                 false => "clean",
             };
             let clean_target: Option<Vec<PathBuf>> = Some(vec!["-t".into(), tool.into()]);
-            ninja_run(ninja_build_file.as_path(), verbose > 0, clean_target)?;
+            ninja_run(ninja_build_file.as_path(), verbose > 0, clean_target, None)?;
         }
         _ => {}
     };
